==> okta-sdk-api-20.0.1-sources.jar: com/okta/sdk/resource/model/OAuth2RefreshTokenLinksAllOfRevokeAllOfHints.java <==
package com.okta.sdk.resource.model;

import java.util.Objects;
import java.util.Arrays;
import com.fasterxml.jackson.annotation.JsonInclude;
import com.fasterxml.jackson.annotation.JsonProperty;
import com.fasterxml.jackson.annotation.JsonCreator;
import com.fasterxml.jackson.annotation.JsonTypeName;
import com.fasterxml.jackson.annotation.JsonValue;
import java.util.ArrayList;
import java.util.Arrays;
import java.util.List;
import java.io.Serializable;
import com.fasterxml.jackson.annotation.JsonPropertyOrder;
import com.fasterxml.jackson.annotation.JsonTypeName;
import io.swagger.annotations.ApiModelProperty;
import io.swagger.annotations.ApiModel;

/**
 * OAuth2RefreshTokenLinksAllOfRevokeAllOfHints
 */
@JsonPropertyOrder({ OAuth2RefreshTokenLinksAllOfRevokeAllOfHints.JSON_PROPERTY_ALLOW })
@JsonTypeName("OAuth2RefreshToken__links_allOf_revoke_allOf_hints")
@jakarta.annotation.Generated(value = "org.openapitools.codegen.languages.JavaClientCodegen", date = "2025-01-23T09:50:29.349096-06:00[America/Chicago]", comments = "Generator version: 7.8.0")
public class OAuth2RefreshTokenLinksAllOfRevokeAllOfHints implements Serializable {

    private static final long serialVersionUID = 1L;

    /**
     * Gets or Sets allow
     */
    public enum AllowEnum {
        DELETE("DELETE"),

        UNKNOWN_DEFAULT_OPEN_API("unknown_default_open_api");

        private String value;

        AllowEnum(String value) {
            this.value = value;
        }

        @JsonValue
        public String getValue() {
            return value;
        }

        @Override
        public String toString() {
            return String.valueOf(value);
        }

        @JsonCreator
        public static AllowEnum fromValue(String value) {
            for (AllowEnum b : AllowEnum.values()) {
                if (b.value.equals(value)) {
                    return b;
                }
            }
            return UNKNOWN_DEFAULT_OPEN_API;
        }
    }

    public static final String JSON_PROPERTY_ALLOW = "allow";
    private List<AllowEnum> allow = null;

    public OAuth2RefreshTokenLinksAllOfRevokeAllOfHints() {
    }

    public OAuth2RefreshTokenLinksAllOfRevokeAllOfHints allow(List<AllowEnum> allow) {

        this.allow = allow;
        return this;
    }

    public OAuth2RefreshTokenLinksAllOfRevokeAllOfHints addallowItem(AllowEnum allowItem) {
        if (this.allow == null) {
            this.allow = new ArrayList<>();
        }
        this.allow.add(allowItem);
        return this;
    }

    /**
     * Get allow
     *
     * @return allow
     **/
    @javax.annotation.Nullable
    @ApiModelProperty(value = "")
    @JsonProperty(JSON_PROPERTY_ALLOW)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)

    public List<AllowEnum> getAllow() {
        return allow;
    }

    @JsonProperty(JSON_PROPERTY_ALLOW)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)
    public void setAllow(List<AllowEnum> allow) {
        this.allow = allow;
    }

    @Override
    public boolean equals(Object o) {
        if (this == o) {
            return true;
        }
        if (o == null || getClass() != o.getClass()) {
            return false;
        }
        OAuth2RefreshTokenLinksAllOfRevokeAllOfHints oauth2RefreshTokenLinksAllOfRevokeAllOfHints = (OAuth2RefreshTokenLinksAllOfRevokeAllOfHints) o;
        return Objects.equals(this.allow, oauth2RefreshTokenLinksAllOfRevokeAllOfHints.allow);
        // ;
    }

    @Override
    public int hashCode() {
        return Objects.hash(allow);
    }

    @Override
    public String toString() {
        StringBuilder sb = new StringBuilder();
        sb.append("class OAuth2RefreshTokenLinksAllOfRevokeAllOfHints {\n");
        sb.append("    allow: ").append(toIndentedString(allow)).append("\n");
        sb.append("}");
        return sb.toString();
    }

    /**
     * Convert the given object to string with each line indented by 4 spaces (except the first line).
     */
    private String toIndentedString(Object o) {
        if (o == null) {
            return "null";
        }
        return o.toString().replace("\n", "\n    ");
    }

}

==> okta-sdk-api-21.0.0-sources.jar: com/okta/sdk/resource/model/OAuth2RefreshTokenLinksAllOfRevokeAllOfHints.java <==
package com.okta.sdk.resource.model;

import java.util.Objects;
import java.util.Arrays;
import com.fasterxml.jackson.annotation.JsonInclude;
import com.fasterxml.jackson.annotation.JsonProperty;
import com.fasterxml.jackson.annotation.JsonCreator;
import com.fasterxml.jackson.annotation.JsonTypeName;
import com.fasterxml.jackson.annotation.JsonValue;
import java.util.ArrayList;
import java.util.Arrays;
import java.util.List;
import java.io.Serializable;
import com.fasterxml.jackson.annotation.JsonPropertyOrder;
import com.fasterxml.jackson.annotation.JsonTypeName;
import io.swagger.annotations.ApiModelProperty;
import io.swagger.annotations.ApiModel;

/**
 * OAuth2RefreshTokenLinksAllOfRevokeAllOfHints
 */
@JsonPropertyOrder({ OAuth2RefreshTokenLinksAllOfRevokeAllOfHints.JSON_PROPERTY_ALLOW })
@JsonTypeName("OAuth2RefreshToken__links_allOf_revoke_allOf_hints")
@jakarta.annotation.Generated(value = "org.openapitools.codegen.languages.JavaClientCodegen", date = "2025-02-24T22:29:38.763116-06:00[America/Chicago]", comments = "Generator version: 7.11.0")
public class OAuth2RefreshTokenLinksAllOfRevokeAllOfHints implements Serializable {

    private static final long serialVersionUID = 1L;

    /**
     * Gets or Sets allow
     */
    public enum AllowEnum {
        DELETE(String.valueOf("DELETE")),

        UNKNOWN_DEFAULT_OPEN_API(String.valueOf("unknown_default_open_api"));

        private String value;

        AllowEnum(String value) {
            this.value = value;
        }

        @JsonValue
        public String getValue() {
            return value;
        }

        @Override
        public String toString() {
            return String.valueOf(value);
        }

        @JsonCreator
        public static AllowEnum fromValue(String value) {
            for (AllowEnum b : AllowEnum.values()) {
                if (b.value.equals(value)) {
                    return b;
                }
            }
            return UNKNOWN_DEFAULT_OPEN_API;
        }
    }

    public static final String JSON_PROPERTY_ALLOW = "allow";
    private List<AllowEnum> allow = null;

    public OAuth2RefreshTokenLinksAllOfRevokeAllOfHints() {
    }

    public OAuth2RefreshTokenLinksAllOfRevokeAllOfHints allow(List<AllowEnum> allow) {

        this.allow = allow;
        return this;
    }

    public OAuth2RefreshTokenLinksAllOfRevokeAllOfHints addallowItem(AllowEnum allowItem) {
        if (this.allow == null) {
            this.allow = new ArrayList<>();
        }
        this.allow.add(allowItem);
        return this;
    }

    /**
     * Get allow
     *
     * @return allow
     **/
    @javax.annotation.Nullable
    @ApiModelProperty(value = "")
    @JsonProperty(JSON_PROPERTY_ALLOW)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)

    public List<AllowEnum> getAllow() {
        return allow;
    }

    @JsonProperty(JSON_PROPERTY_ALLOW)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)
    public void setAllow(List<AllowEnum> allow) {
        this.allow = allow;
    }

    @Override
    public boolean equals(Object o) {
        if (this == o) {
            return true;
        }
        if (o == null || getClass() != o.getClass()) {
            return false;
        }
        OAuth2RefreshTokenLinksAllOfRevokeAllOfHints oauth2RefreshTokenLinksAllOfRevokeAllOfHints = (OAuth2RefreshTokenLinksAllOfRevokeAllOfHints) o;
        return Objects.equals(this.allow, oauth2RefreshTokenLinksAllOfRevokeAllOfHints.allow);
        // ;
    }

    @Override
    public int hashCode() {
        return Objects.hash(allow);
    }

    @Override
    public String toString() {
        StringBuilder sb = new StringBuilder();
        sb.append("class OAuth2RefreshTokenLinksAllOfRevokeAllOfHints {\n");
        sb.append("    allow: ").append(toIndentedString(allow)).append("\n");
        sb.append("}");
        return sb.toString();
    }

    /**
     * Convert the given object to string with each line indented by 4 spaces (except the first line).
     */
    private String toIndentedString(Object o) {
        if (o == null) {
            return "null";
        }
        return o.toString().replace("\n", "\n    ");
    }

}
